@@ -1,4 +1,7 @@
 from .firefly_client import FireflyClient
+from .ffws import FFWs
+from .env import Env
+from .range_values import RangeValues
 import pkg_resources
 
 __version__ = pkg_resources.get_distribution("firefly_client").version
